# -*- coding: utf-8 -*-

import doctest
import unittest
import menhir.contenttype.file
from zope.component.testlayer import ZCMLFileLayer


def test_suite():
    suite = unittest.TestSuite()
    readme = doctest.DocFileSuite(
        'README.txt',
        globs={"__name__": "menhir.contenttype.file"},
        optionflags=(doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS))
    readme.layer = ZCMLFileLayer(menhir.contenttype.file)
    suite.addTest(readme)
    return suite



# -*- coding: utf-8 -*-

import dolmen.content as content
from dolmen.file import FileField
from dolmen.blob import BlobProperty
from dolmen.app.content import icon
from dolmen.app.security import content as security
from menhir.contenttype.file import MF as _


class IFile(content.IBaseContent):
    """A simple file object.
    """
    data = FileField(
        title=_(u"File"),
        required=True)


class File(content.Content):
    """A file content type storing the data in blobs.
    """
    icon("file.png")
    content.name(_(u"File"))
    content.schema(IFile)
    content.require(security.CanAddContent)

    data = BlobProperty(IFile['data'])



from os.path import join
from setuptools import setup, find_packages

version = '0.1'

readme = open(join("src", "menhir", "contenttype", "file", "README.txt")).read()
change = open(join("docs", "HISTORY.txt")).read()

tests_require = [
    'zope.component',
    'zope.publisher',
    ]

setup(name='menhir.contenttype.file',
      version=version,
      description="File content type for Grok and Dolmen applications.",
      long_description=readme + '\n' + change,
      classifiers=[
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='',
      author='',
      author_email='',
      url='',
      license='GPL',
      packages=find_packages('src', exclude=['ez_setup']),
      package_dir={'': 'src'},
      namespace_packages=['menhir', 'menhir.contenttype'],
      include_package_data=True,
      zip_safe=False,
      tests_require = tests_require,
      extras_require = {'test': tests_require},
      install_requires=[
          'dolmen.app.content',
          'dolmen.app.security',
          'dolmen.blob',
          'dolmen.content',
          'dolmen.file',
          'setuptools',
          'zope.i18n',
          'zope.i18nmessageid',
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )
